==> blotoutfluttersdk-0.0.9.tar.gz: lib/src/BlotoutAnalytics.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class BlotoutAnalyticsAPI {
  static const String _pluginName = 'blotoutfluttersdk';

  static const MethodChannel _channel = const MethodChannel(_pluginName);

  BlotoutAnalyticsAPI._privateConstructor();

  static final BlotoutAnalyticsAPI blotoutAnalyticsInstance =
      BlotoutAnalyticsAPI._privateConstructor();

  factory BlotoutAnalyticsAPI() {
    return blotoutAnalyticsInstance;
  }

  /*
  *
  * this initializes the BlotoutAnalytics tracking configuration, it has to be called only once when the
  * application starts, for example in the Application Class or the Main Activities onCreate.
  * @param context Application context of the application
  * @param blotoutSDKKey stage key as String
  * @param endPointUrl server Endpoint Url e.g. https://blotout.io, http://blotout.io 
  */
  Future<bool> initBlotoutSDK(String blotoutSDKKey, String endPointUrl) async {
    Map<String, dynamic> properties = <String, dynamic>{
      'blotoutSDKKey': blotoutSDKKey,
      'endPoint': endPointUrl
    };

    bool sdkInitialized =
        await _channel.invokeMethod<bool>('initBlotoutSDK', properties);
    return sdkInitialized;
  }

  /* This Method is used to set End Point Url where we have to send the data
  * Server Endpoint Url e.g. https://blotout.io, http://blotout.io
  * SDK Endpoint Url must be set before Analytics Engine Initialization, It has to be a domain based IP's are considered invalid.
  * @param endPointUrl
  */
  void setSDKEndPointUrl(String endPointUrl) {
    Map<String, dynamic> properties = <String, dynamic>{
      'endPoint': endPointUrl
    };

    _channel.invokeMethod<void>('setSDKEndPointUrl', properties);
  }

  /*
  * @param enabled default is true, set false to disable the sdk
  */
  void setSDKEnabled(bool sdkEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'sdkEnabled': sdkEnabled
    };

    _channel.invokeMethod<void>('setSDKEnabled', eventData);
  }

/*
 * This method is use to send event to server based on EventName
 * @param eventName name of the event
 * @param startEventInfo properties in key/value pair
 */
  void logEvent(String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('logEvent', eventData);
  }

/*
 * This method is use to send event with time to server based on EventName
 * @param eventName name of the event
 * @param endEventInfo properties in key/value pair
 */
  void logEventWithTime(
      String eventName, Map<String, dynamic> properties, DateTime happenedAt) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties,
      'time': happenedAt.millisecondsSinceEpoch
    };

    _channel.invokeMethod<void>('logEventWithTime', eventData);
  }

/*
 * This method is use to create an event with start time and will finish this event using endTimedEvent
 * Mainly used to measure a event based on time
 * @param eventName name of the event
 * @param eventInfo properties in key/value pair
 */
  void startTimedEvent(String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('startTimedEvent', eventData);
  }

/*
 * This Method is use to end a event that is creted using startTimedEvent
 * @param eventName name of the event
 * @param eventInfo properties in key/value pair
 */
  void endTimedEvent(String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('endTimedEvent', eventData);
  }

/* 
* @param eventName name of the event
* @param eventInfo properties in key/value pair
*/
  void logUserRetentionEvent(
      String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('logUserRetentionEvent', eventData);
  }

  /*
  * This Methis is used to send PII events that will send data to server in encrypted format
  * @param eventName name of the event as String
  * @param eventInfo properties in key/value pair
  * @param eventTime eventTime as Date
  *
  */
  void logPIIEvent(
      String eventName, Map<String, dynamic> properties, DateTime happenedAt) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties,
      'time': happenedAt.millisecondsSinceEpoch
    };

    _channel.invokeMethod<void>('logPIIEvent', eventData);
  }

  /*
  * This Methis is used to send PHI events that will send data to server in encrypted format
  * @param eventName name of the event as String
  * @param eventInfo properties in key/value pair
  * @param eventTime eventTime as Date
  *
  */
  void logPHIEvent(
      String eventName, Map<String, dynamic> properties, DateTime happenedAt) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties,
      'time': happenedAt.millisecondsSinceEpoch
    };

    _channel.invokeMethod<void>('logPHIEvent', eventData);
  }

  /*
 * @param networkSyncEnabled default is true, set false to disable the Network call
 */

  void setNetworkSyncEnabled(bool networkSyncEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': networkSyncEnabled
    };

    _channel.invokeMethod<void>('setNetworkSyncEnabled', eventData);
  }

/*
 * @param dataCollectionEnabled default is true, set false to disable data collection
 */

  void setDataCollectionEnabled(bool dataCollectionEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': dataCollectionEnabled
    };

    _channel.invokeMethod<void>('setDataCollectionEnabled', eventData);
  }

/*
 *
 * @param funnelEventsEnabled default is true, set false to disable funnel execution
 */

  void setFunnelEventsEnabled(bool funnelEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': funnelEventsEnabled
    };

    _channel.invokeMethod<void>('setFunnelEventsEnabled', eventData);
  }

/*
 *
 * @param segmentEventsEnabled default is true, set false to disable segment execution
 */

  void setSegmentEventsEnabled(bool segmentEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': segmentEventsEnabled
    };

    _channel.invokeMethod<void>('setSegmentEventsEnabled', eventData);
  }

/*
 * @param retentionEventsEnabled default is true, set false to disable retention events execution
 */

  void setRetentionEventsEnabled(bool retentionEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': retentionEventsEnabled
    };

    _channel.invokeMethod<void>('setRetentionEventsEnabled', eventData);
  }

/*
 *
 * @param developerEventsEnabled default is true, set false to disable developer events execution
 */

  void setDeveloperEventsEnabled(bool developerEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': developerEventsEnabled
    };

    _channel.invokeMethod<void>('setDeveloperEventsEnabled', eventData);
  }

/*
 *
 * @param systemEventsEnabled default is true, set false to disable device/system events execution
 */

  void setSystemEventsEnabled(bool systemEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': systemEventsEnabled
    };

    _channel.invokeMethod<void>('setSystemEventsEnabled', eventData);
  }

/*
 *
 * @param payingUser default is false, set true to enable the payingUser analytics
 */

  void setPayingUser(bool payingUser) {
    Map<String, dynamic> eventData = <String, dynamic>{'enabled': payingUser};

    _channel.invokeMethod<void>('setPayingUser', eventData);
  }

  //Fraud Services
  Future<bool> isDeviceCompromised() async {
    bool value = await _channel.invokeMethod<bool>('isDeviceCompromised');
    return value;
  }

  //Fraud Services
  Future<bool> isAppCompromised() async {
    bool value = await _channel.invokeMethod<bool>('isAppCompromised');
    return value;
  }

//Fraud Services
  Future<bool> isNetworkProxied() async {
    bool value = await _channel.invokeMethod<bool>('isNetworkProxied');
    return value;
  }

//Fraud Services
  Future<bool> isSimulator() async {
    bool value = await _channel.invokeMethod<bool>('isSimulator');
    return value;
  }

//Fraud Services
  Future<bool> isRunningOnVM() async {
    bool value = await _channel.invokeMethod<bool>('isRunningOnVM');
    return value;
  }

//Fraud Services
  Future<bool> isEnvironmentSecure() async {
    bool value = await _channel.invokeMethod<bool>('isEnvironmentSecure');
    return value;
  }
}

==> blotoutfluttersdk-0.0.11.tar.gz: lib/src/BlotoutAnalytics.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

class BlotoutAnalyticsAPI {
  static const String _pluginName = 'blotoutfluttersdk';

  static const MethodChannel _channel = const MethodChannel(_pluginName);

  BlotoutAnalyticsAPI._privateConstructor();

  static final BlotoutAnalyticsAPI blotoutAnalyticsInstance =
      BlotoutAnalyticsAPI._privateConstructor();

  factory BlotoutAnalyticsAPI() {
    return blotoutAnalyticsInstance;
  }

  /*
  *
  * this initializes the BlotoutAnalytics tracking configuration, it has to be called only once when the
  * application starts, for example in the Application Class or the Main Activities onCreate.
  * @param context Application context of the application
  * @param blotoutSDKKey stage key as String
  * @param endPointUrl server Endpoint Url e.g. https://blotout.io, http://blotout.io 
  */
  Future<bool> initBlotoutSDK(String blotoutSDKKey, String endPointUrl) async {
    Map<String, dynamic> properties = <String, dynamic>{
      'blotoutSDKKey': blotoutSDKKey,
      'endPoint': endPointUrl
    };

    bool sdkInitialized =
        await _channel.invokeMethod<bool>('initBlotoutSDK', properties);
    return sdkInitialized;
  }

  /*
  * @param enabled default is true, set false to disable the sdk
  */
  void setSDKEnabled(bool sdkEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'sdkEnabled': sdkEnabled
    };

    _channel.invokeMethod<void>('setSDKEnabled', eventData);
  }

  /*
  * This Method is used to enable sdk logs
  * @param SDKLogEnabled value as true or false, default value is false.
  */
  void setSDKLogEnabled(bool sdkLogEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'sdkLogEnabled': sdkLogEnabled
    };

    _channel.invokeMethod<void>('setSDKLogEnabled', eventData);
  }

/*
 * This method is use to send event to server based on EventName
 * @param eventName name of the event
 * @param startEventInfo properties in key/value pair
 */
  void logEvent(String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('logEvent', eventData);
  }

/*
 * This method is use to send event with time to server based on EventName
 * @param eventName name of the event
 * @param endEventInfo properties in key/value pair
 */
  void logEventWithTime(
      String eventName, Map<String, dynamic> properties, DateTime happenedAt) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties,
      'time': happenedAt.millisecondsSinceEpoch
    };

    _channel.invokeMethod<void>('logEventWithTime', eventData);
  }

/*
 * This method is use to create an event with start time and will finish this event using endTimedEvent
 * Mainly used to measure a event based on time
 * @param eventName name of the event
 * @param eventInfo properties in key/value pair
 */
  void startTimedEvent(String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('startTimedEvent', eventData);
  }

/*
 * This Method is use to end a event that is creted using startTimedEvent
 * @param eventName name of the event
 * @param eventInfo properties in key/value pair
 */
  void endTimedEvent(String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('endTimedEvent', eventData);
  }

/* 
* @param eventName name of the event
* @param eventInfo properties in key/value pair
*/
  void logUserRetentionEvent(
      String eventName, Map<String, dynamic> properties) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties
    };

    _channel.invokeMethod<void>('logUserRetentionEvent', eventData);
  }

  /*
  * This Methis is used to send PII events that will send data to server in encrypted format
  * @param eventName name of the event as String
  * @param eventInfo properties in key/value pair
  * @param eventTime eventTime as Date
  *
  */
  void logPIIEvent(
      String eventName, Map<String, dynamic> properties, DateTime happenedAt) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties,
      'time': happenedAt.millisecondsSinceEpoch
    };

    _channel.invokeMethod<void>('logPIIEvent', eventData);
  }

  /*
  * This Methis is used to send PHI events that will send data to server in encrypted format
  * @param eventName name of the event as String
  * @param eventInfo properties in key/value pair
  * @param eventTime eventTime as Date
  *
  */
  void logPHIEvent(
      String eventName, Map<String, dynamic> properties, DateTime happenedAt) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'eventName': eventName,
      'properties': properties,
      'time': happenedAt.millisecondsSinceEpoch
    };

    _channel.invokeMethod<void>('logPHIEvent', eventData);
  }

  /*
 * @param networkSyncEnabled default is true, set false to disable the Network call
 */

  void setNetworkSyncEnabled(bool networkSyncEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': networkSyncEnabled
    };

    _channel.invokeMethod<void>('setNetworkSyncEnabled', eventData);
  }

/*
 * @param dataCollectionEnabled default is true, set false to disable data collection
 */

  void setDataCollectionEnabled(bool dataCollectionEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': dataCollectionEnabled
    };

    _channel.invokeMethod<void>('setDataCollectionEnabled', eventData);
  }

/*
 *
 * @param funnelEventsEnabled default is true, set false to disable funnel execution
 */

  void setFunnelEventsEnabled(bool funnelEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': funnelEventsEnabled
    };

    _channel.invokeMethod<void>('setFunnelEventsEnabled', eventData);
  }

/*
 *
 * @param segmentEventsEnabled default is true, set false to disable segment execution
 */

  void setSegmentEventsEnabled(bool segmentEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': segmentEventsEnabled
    };

    _channel.invokeMethod<void>('setSegmentEventsEnabled', eventData);
  }

/*
 * @param retentionEventsEnabled default is true, set false to disable retention events execution
 */

  void setRetentionEventsEnabled(bool retentionEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': retentionEventsEnabled
    };

    _channel.invokeMethod<void>('setRetentionEventsEnabled', eventData);
  }

/*
 *
 * @param developerEventsEnabled default is true, set false to disable developer events execution
 */

  void setDeveloperEventsEnabled(bool developerEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': developerEventsEnabled
    };

    _channel.invokeMethod<void>('setDeveloperEventsEnabled', eventData);
  }

/*
 *
 * @param systemEventsEnabled default is true, set false to disable device/system events execution
 */

  void setSystemEventsEnabled(bool systemEventsEnabled) {
    Map<String, dynamic> eventData = <String, dynamic>{
      'enabled': systemEventsEnabled
    };

    _channel.invokeMethod<void>('setSystemEventsEnabled', eventData);
  }

/*
 *
 * @param payingUser default is false, set true to enable the payingUser analytics
 */

  void setPayingUser(bool payingUser) {
    Map<String, dynamic> eventData = <String, dynamic>{'enabled': payingUser};

    _channel.invokeMethod<void>('setPayingUser', eventData);
  }

  //Fraud Services
  Future<bool> isDeviceCompromised() async {
    bool value = await _channel.invokeMethod<bool>('isDeviceCompromised');
    return value;
  }

  //Fraud Services
  Future<bool> isAppCompromised() async {
    bool value = await _channel.invokeMethod<bool>('isAppCompromised');
    return value;
  }

//Fraud Services
  Future<bool> isNetworkProxied() async {
    bool value = await _channel.invokeMethod<bool>('isNetworkProxied');
    return value;
  }

//Fraud Services
  Future<bool> isSimulator() async {
    bool value = await _channel.invokeMethod<bool>('isSimulator');
    return value;
  }

//Fraud Services
  Future<bool> isRunningOnVM() async {
    bool value = await _channel.invokeMethod<bool>('isRunningOnVM');
    return value;
  }

//Fraud Services
  Future<bool> isEnvironmentSecure() async {
    bool value = await _channel.invokeMethod<bool>('isEnvironmentSecure');
    return value;
  }
}
